==> nextcloud-28.0.3.tgz: nextcloud/apps/workflowengine/l10n/mk.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Зададениот оператор не е валиден",
    "The given regular expression is invalid" : "Зададеното регуларно изразување е невалидно",
    "The given file size is invalid" : "Зададената големина на датотека е невалидна",
    "The given tag id is invalid" : "Зададениот ИД за ознака е невалиден",
    "The given IP range is invalid" : "Зададениот ИП опсег е невалиден",
    "The given IP range is not valid for IPv4" : "Зададениот ИП опсег е невалиден за IPv4",
    "The given IP range is not valid for IPv6" : "Зададениот ИП опсег е невалиден за IPv6",
    "The given time span is invalid" : "Зададениот временски опсег е невалиден",
    "The given start time is invalid" : "Зададеното почетно време е невалидно",
    "The given end time is invalid" : "Зададеното завршно време е невалидно",
    "The given group does not exist" : "Зададената група не постои",
    "File" : "Датотека",
    "File created" : "Датотека е креирана",
    "File updated" : "Датотека е прикачена",
    "File renamed" : "Датотека е преименувана",
    "File deleted" : "Датотека е избришана",
    "File accessed" : "Пристапено до датотека",
    "File copied" : "Датотека е копирана",
    "Tag assigned" : "Доделена ознака",
    "Someone" : "Некој",
    "%s created %s" : "%s креираше%s",
    "%s modified %s" : "%s измени %s",
    "%s deleted %s" : "%s избриша %s",
    "%s accessed %s" : "%s пристапи %s",
    "%s renamed %s" : "%s преименува %s",
    "%s copied %s" : "%s копираше %s",
    "%s assigned %s to %s" : "%s пристапи %s до %s",
    "Operation #%s does not exist" : "Операцијата #%s не постои",
    "Entity %s does not exist" : "Субјектот %s не постои",
    "Entity %s is invalid" : "Субјектот %s е невалиден",
    "No events are chosen." : "Не е избран настан.",
    "Entity %s has no event %s" : "Субјектот %s нема настан %s",
    "Operation %s does not exist" : "Операцијата %s не постои",
    "Operation %s is invalid" : "Операцијата %s е невалидна",
    "Flow" : "Проток",
    "Select a filter" : "Изберете филтер",
    "Select a comparator" : "Изберете компаратор",
    "Select a file type" : "Изберете вид на датотека",
    "e.g. httpd/unix-directory" : "Пр. httpd/unix-directory",
    "Folder" : "Папка",
    "Images" : "Слики",
    "Office documents" : "Office документи",
    "PDF documents" : "PDF документи",
    "Custom mimetype" : "Прилагоден тип на датотеки",
    "Please enter a valid time span" : "Внесете валиден времески осег",
    "Desktop client" : "Клиент за компјутер",
    "When" : "Кога",
    "and" : "и",
    "Cancel" : "Откажи",
    "Delete" : "Избриши",
    "Active" : "Активно",
    "Save" : "Зачувај",
    "Available flows" : "Достапни протоци",
    "For details on how to write your own flow, check out the development documentation." : "За детали како да пишувате ваши сопствени протоци, посетете ја документацијата за развивачи.",
    "More flows" : "Повеќе протоци",
    "Browse the App Store" : "Прелистајте во продавницата со апликации",
    "Show less" : "Помалку",
    "Show more" : "Прикажи повеќе",
    "Configured flows" : "Конфигурирани протоци",
    "Your flows" : "Ваши протоци",
    "matches" : "се совпаѓа",
    "does not match" : "не се совпаѓа",
    "is" : "е",
    "is not" : "не е",
    "File name" : "Име на датотека",
    "File MIME type" : "Вид на датотека",
    "File size (upload)" : "Големина на датотека (прикачи)",
    "less" : "помалку",
    "less or equals" : "помалку или еднакво",
    "greater or equals" : "поголемо или еднакво",
    "greater" : "поголемо",
    "matches IPv4" : "се совпаѓањаат IPv4",
    "does not match IPv4" : "не се совпаѓаат IPv4",
    "matches IPv6" : "се совпаѓањаат IPv6",
    "does not match IPv6" : "не се совпаѓаат IPv6",
    "File system tag" : "Датотека со системска ознака",
    "is tagged with" : "е означена со",
    "is not tagged with" : "не е означена со",
    "between" : "помеѓу",
    "not between" : "не помеѓу",
    "is member of" : "е член на",
    "is not member of" : "не е член на"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-31.0.11.tgz: nextcloud/apps/workflowengine/l10n/mk.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Зададениот оператор не е валиден",
    "The given regular expression is invalid" : "Зададеното регуларно изразување е невалидно",
    "The given file size is invalid" : "Зададената големина на датотека е невалидна",
    "The given tag id is invalid" : "Зададениот ИД за ознака е невалиден",
    "The given IP range is invalid" : "Зададениот ИП опсег е невалиден",
    "The given IP range is not valid for IPv4" : "Зададениот ИП опсег е невалиден за IPv4",
    "The given IP range is not valid for IPv6" : "Зададениот ИП опсег е невалиден за IPv6",
    "The given time span is invalid" : "Зададениот временски опсег е невалиден",
    "The given start time is invalid" : "Зададеното почетно време е невалидно",
    "The given end time is invalid" : "Зададеното завршно време е невалидно",
    "The given group does not exist" : "Зададената група не постои",
    "File" : "Датотека",
    "File created" : "Датотека е креирана",
    "File updated" : "Датотека е прикачена",
    "File renamed" : "Датотека е преименувана",
    "File deleted" : "Датотека е избришана",
    "File accessed" : "Пристапено до датотека",
    "File copied" : "Датотека е копирана",
    "Tag assigned" : "Доделена ознака",
    "Someone" : "Некој",
    "%s created %s" : "%s креираше%s",
    "%s modified %s" : "%s измени %s",
    "%s deleted %s" : "%s избриша %s",
    "%s accessed %s" : "%s пристапи %s",
    "%s renamed %s" : "%s преименува %s",
    "%s copied %s" : "%s копираше %s",
    "Operation #%s does not exist" : "Операцијата #%s не постои",
    "Entity %s does not exist" : "Субјектот %s не постои",
    "Entity %s is invalid" : "Субјектот %s е невалиден",
    "No events are chosen." : "Не е избран настан.",
    "Entity %s has no event %s" : "Субјектот %s нема настан %s",
    "Operation %s does not exist" : "Операцијата %s не постои",
    "Operation %s is invalid" : "Операцијата %s е невалидна",
    "Flow" : "Проток",
    "Select a filter" : "Изберете филтер",
    "Select a comparator" : "Изберете компаратор",
    "Remove filter" : "Отстрани филтер",
    "Audio" : "Аудио",
    "Folder" : "Папка",
    "Images" : "Слики",
    "Office documents" : "Office документи",
    "PDF documents" : "PDF документи",
    "Video" : "Видео",
    "Select a file type" : "Изберете вид на датотека",
    "e.g. httpd/unix-directory" : "Пр. httpd/unix-directory",
    "Please enter a valid time span" : "Внесете валиден времески осег",
    "Android client" : "Android клиент",
    "iOS client" : "iOS клиент",
    "Desktop client" : "Клиент за компјутер",
    "Select groups" : "Одбери групи",
    "Groups" : "Групи",
    "Select a trigger" : "Избери активатор",
    "At least one event must be selected" : "Најмалку едно мора да биде означено",
    "Add new flow" : "Додади нов проток",
    "Active" : "Активно",
    "Save" : "Зачувај",
    "When" : "Кога",
    "and" : "и",
    "Add a new filter" : "Додади нов филтер",
    "Cancel" : "Откажи",
    "Delete" : "Избриши",
    "Available flows" : "Достапни протоци",
    "For details on how to write your own flow, check out the development documentation." : "За детали како да пишувате ваши сопствени протоци, посетете ја документацијата за развивачи.",
    "More flows" : "Повеќе протоци",
    "Browse the App Store" : "Прелистајте во продавницата со апликации",
    "Show less" : "Помалку",
    "Show more" : "Прикажи повеќе",
    "Configured flows" : "Конфигурирани протоци",
    "Your flows" : "Ваши протоци",
    "No flows configured" : "Нема конфигурирано проток",
    "matches" : "се совпаѓа",
    "does not match" : "не се совпаѓа",
    "is" : "е",
    "is not" : "не е",
    "File name" : "Име на датотека",
    "File MIME type" : "Вид на датотека",
    "File size (upload)" : "Големина на датотека (прикачи)",
    "less" : "помалку",
    "less or equals" : "помалку или еднакво",
    "greater or equals" : "поголемо или еднакво",
    "greater" : "поголемо",
    "Request remote address" : "Барање од надворешна адреса",
    "matches IPv4" : "се совпаѓаат IPv4",
    "does not match IPv4" : "не се совпаѓаат IPv4",
    "matches IPv6" : "се совпаѓаат IPv6",
    "does not match IPv6" : "не се совпаѓаат IPv6",
    "File system tag" : "Датотека со системска ознака",
    "is tagged with" : "е означена со",
    "is not tagged with" : "не е означена со",
    "Request URL" : "Барање URL",
    "Request time" : "Време на барање",
    "between" : "помеѓу",
    "not between" : "не помеѓу",
    "Request user agent" : "Барање од кориснички агент",
    "is member of" : "е член на",
    "is not member of" : "не е член на"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
